@@ -51,7 +51,9 @@ class BigQueryDataSource(DataSource):
 
     def __init__(self, logs: Logs, data_source_name: str, data_source_properties: dict):
         super().__init__(logs, data_source_name, data_source_properties)
-        self.dataset_name = data_source_properties.get("dataset")
+
+        # Authentication parameters
+        self.account_info_dict = None
 
         account_info_json_str = None
         account_info_path = self.data_source_properties.get("account_info_json_path")
@@ -65,31 +67,48 @@ class BigQueryDataSource(DataSource):
 
         if account_info_json_str:
             self.account_info_dict = json.loads(account_info_json_str)
-        else:
-            logger.error(f"No bigquery connection authentication: no account_info_json nor account_info_json_path")
 
+        default_auth_scopes = [
+            "https://www.googleapis.com/auth/bigquery",
+            "https://www.googleapis.com/auth/cloud-platform",
+            "https://www.googleapis.com/auth/drive",
+        ]
+        self.auth_scopes = data_source_properties.get("auth_scopes", default_auth_scopes)
+
+        self.credentials = None
+        if self.account_info_dict:
+            self.credentials = Credentials.from_service_account_info(
+                self.account_info_dict,
+                scopes=self.auth_scopes,
+            )
+
+        # All remaining parameters
         # Usually the project_id comes from the self.account_info_dict
         self.project_id = self.account_info_dict.get("project_id") if self.account_info_dict else None
         # But users can optionally overwrite in the connection properties
         self.project_id = data_source_properties.get("project_id", self.project_id)
 
-        self.credentials = Credentials.from_service_account_info(
-            self.account_info_dict,
-            scopes=[
-                "https://www.googleapis.com/auth/bigquery",
-                "https://www.googleapis.com/auth/cloud-platform",
-                "https://www.googleapis.com/auth/drive",
-            ],
-        )
+        self.dataset = data_source_properties.get("dataset")
+        # Set schema and table prefix to the same value as dataset, we need one attribute to access this value as it's used in building sql statements.
+        self.update_schema(self.dataset)
+
+        self.location = data_source_properties.get("location")
+        self.client_info = data_source_properties.get("client_info")
+        self.client_options = data_source_properties.get("client_options")
 
     def connect(self):
+        if not self.credentials:
+            self.logs.info("Using application default credentials.")
         try:
             self.client = bigquery.Client(
                 project=self.project_id,
                 credentials=self.credentials,
                 default_query_job_config=bigquery.QueryJobConfig(
-                    default_dataset=f"{self.project_id}.{self.dataset_name}",
+                    default_dataset=f"{self.project_id}.{self.dataset}",
                 ),
+                location=self.location,
+                client_info=self.client_info,
+                client_options=self.client_options,
             )
             self.connection = dbapi.Connection(self.client)
 
@@ -174,10 +193,10 @@ class BigQueryDataSource(DataSource):
         return super().get_metric_sql_aggregation_expression(metric_name, metric_args, expr)
 
     def sql_information_schema_tables(self) -> str:
-        return f"{self.schema}.INFORMATION_SCHEMA.TABLES"
+        return f"{self.dataset}.INFORMATION_SCHEMA.TABLES"
 
     def sql_information_schema_columns(self) -> str:
-        return f"{self.schema}.INFORMATION_SCHEMA.COLUMNS"
+        return f"{self.dataset}.INFORMATION_SCHEMA.COLUMNS"
 
     def default_casify_type_name(self, identifier: str) -> str:
         return identifier.upper()
@@ -196,8 +215,3 @@ class BigQueryDataSource(DataSource):
 
     def sql_union(self):
         return "UNION ALL"
-
-    def create_test_table_manager(self):
-        from tests.bigquery_data_source_fixture import BigQueryDataSourceFixture
-
-        return BigQueryDataSourceFixture(self)
